#
# spec file for package fonttosfnt
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fonttosfnt
Version:        1.2.3
Release:        1.1
Summary:        Utility to wrap a bitmap font in a sfnt (TrueType) wrapper
License:        MIT
Group:          System/X11/Utilities
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontenc)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6

%description
Wrap a bitmap font or a set of bitmap fonts in a sfnt (TrueType or
OpenType) wrapper.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc README.md
%{_bindir}/fonttosfnt
%{_mandir}/man1/fonttosfnt.1%{?ext_man}

%changelog
* Thu Sep 28 2023 Stefan Dirsch <sndirsch@suse.com>
- update to 1.2.3
  * Build xz tarballs instead of bzip2
  * gitlab CI: enable commit & merge request checks
  * gitlab CI: enable gitlab's builtin static analysis
  * Variable scope reductions as recommended by cppcheck
  * args_copy variable is unused if HAVE_DECL_VA_COPY is not defined
  * makeBitmap: declare raster parameter const as recommended by cppcheck
  * Remove unused function findIndex
  * Allow inlining makeName
  * Use C99 compound literals to initialize newly allocated structs
  * Add CI tests
* Tue Jun 15 2021 Stefan Dirsch <sndirsch@suse.com>
- update to 1.2.2
  * fix for recent versions that mixed up font size with font height.
* Tue Dec 22 2020 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * Resolves issues found by Oracle Parfait 4.0 static analyser:
  * Fall back to using FONT property as family name
  * fix sign of calculated descent
  * handle empty foundry encoded as NULL
* Wed Oct 21 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.2.0
  * This release contains a bunch of fixes all over the place
* Tue Jan  7 2020 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.1.0
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Correct a string literal
  * Mention .otb as an extension
  * Accept a BDF font on stdin
  * Avoid undefined behaviour
  * Round font size to integer value when reading bitmap font
  * Mark vsprintf_alloc as printf-like function
  * check for freetype NULL atoms
  * let freetype handle ISO-8859-1 mapping
  * allow ISO-646.1991-IRV as well, adobe standard for bdf
* Fri Aug 17 2018 sndirsch@suse.com
- Update to version 1.0.5
  * Is it a bird? is it a plane? No it's a fonttofs.. fontstof..
    fonttofn... it's a release of the tool that wraps a bitmap
    font into a truetype wrapper! Bringing you the last 9 years
    of exciting changes including ansification and lots of
    autotools cleanup changes, because that is how we rolled 7
    years ago. (Almost) no source files were harmed in the
    making of this release.
- get rid of _service/_servicedata files
* Wed May 31 2017 zaitor@opensuse.org
- Update to version 1.0.5+20170126.aead36f:
  * config:
  - Replace deprecated AM_CONFIG_HEADER with AC_CONFIG_HEADERS.
  - Move man pages into their own directory.
  - Add missing AC_CONFIG_SRCDIR.
  * man:
  - Remove trailing spaces and tabs.
  - Replace hard coded man page section with substitution
    strings.
  * configure: Drop AM_MAINTAINER_MODE.
  * autogen.sh:
  - Honor NOCONFIGURE=1.
  - Use exec instead of waiting for configure to finish.
  - Use quoted string variables.
  - Add default patch prefix.
- Switch to source service git checkout.
- Following the above, add libtool BuildRequires, and pass
  NOCONFIGURE=1 ./autogen.sh: Needed now that we build from a git
  checkout.
- Add pkgconfig(xorg-macros) BuildRequires: New dependency.
- Stop packaging ChangeLog and NEWS, dropped upstream.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split fonttosfnt from xorg-x11. Initial version: 1.0.4.
